<?php

namespace Drupal\mm_webform\Form;

use Drupal\Core\Ajax\AjaxResponse;
use Drupal\Core\Url;
use Drupal\webform\Ajax\WebformRefreshCommand;
use Drupal\webform\WebformEntityHandlersForm;
use Drupal\webform\WebformInterface;
use Symfony\Component\HttpFoundation\RedirectResponse;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpKernel\Exception\NotFoundHttpException;

class MMWebformEntityHandlersForm extends WebformEntityHandlersForm {

  use MMWebformFixEntityTrait;

  /**
   * @inheritDoc
   */
  public static function mmAjaxOperation($webform_handler, $op, Request $request) {
    /** @var WebformInterface $webform */
    if (!$webform = static::getWebformFromRoute()) {
      throw new NotFoundHttpException();
    }
    parent::ajaxOperation($webform, $webform_handler, $op, $request);

    $params = \Drupal::routeMatch()->getParameters();
    $url = new Url('mm_webform.handlers', [
        'mm_tree' => $params->get('mm_tree')->id(),
        'node' => $params->get('node')->id(),
      ],
      ['query' => ['update' => $webform_handler]]
    );

    // If the request is via AJAX, return the webform handlers form.
    if ($request->request->get('js')) {
      $response = new AjaxResponse();
      $response->addCommand(new WebformRefreshCommand($url->toString()));
      return $response;
    }

    // Otherwise, redirect back to the webform handlers form.
    return new RedirectResponse($url);
  }

}
